==> dokuwiki-2012.01.25.tgz: dokuwiki/lib/plugins/acl/lang/it/lang.php <==
<?php
/**
 * Italian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Giorgio Vecchiocattivi <giorgio@vecchio.it>
 * @author Roberto Bolli <http://www.rbnet.it/>
 * @author Pietro Battiston toobaz@email.it
 * @author Diego Pierotto ita.translations@tiscali.it
 * @author ita.translations@tiscali.it
 * @author Lorenzo Breda <lbreda@gmail.com>
 * @author snarchio@alice.it
 * @author robocap <robocap1@gmail.com>
 * @author Osman Tekin osman.tekin93@hotmail.it
 * @author Jacopo Corbetta <jacopo.corbetta@gmail.com>
 */
$lang['admin_acl']             = 'Gestione Lista Controllo Accessi (ACL)';
$lang['acl_group']             = 'Gruppo';
$lang['acl_user']              = 'Utente';
$lang['acl_perms']             = 'Permessi per';
$lang['page']                  = 'Pagina';
$lang['namespace']             = 'Categoria';
$lang['btn_select']            = 'Seleziona';
$lang['p_user_id']             = 'L\'utente <b class="acluser">%s</b> attualmente ha i seguenti permessi sulla pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'L\'utente <b class="acluser">%s</b> attualmente ha i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi sulla pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = '<b>Inserisci un utente o gruppo</b> nel campo sopra per modificare i permessi impostati per la pagina <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = '<b>Inserisci un utente o un gruppo</b> nel campo sopra per modificare i permessi impostati per la categoria <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Nota: questi permessi non sono stati esplicitamente impostati, ma sono stati ereditati da altri gruppi o da categorie superiori.';
$lang['p_isadmin']             = 'Nota: il gruppo o utente selezionato ha sempre tutti i permessi perché è configurato come amministratore.';
$lang['p_include']             = 'I permessi più elevati includono i permessi inferiori. I permessi Crea, Carica ed Elimina si applicano soltanto alle categorie e non alle pagine.';
$lang['current']               = 'Regole ACL attuali';
$lang['where']                 = 'Pagina/Categoria';
$lang['who']                   = 'Utente/Gruppo';
$lang['perm']                  = 'Permessi';
$lang['acl_perm0']             = 'Nessuno';
$lang['acl_perm1']             = 'Lettura';
$lang['acl_perm2']             = 'Modifica';
$lang['acl_perm4']             = 'Crea';
$lang['acl_perm8']             = 'Carica';
$lang['acl_perm16']            = 'Elimina';
$lang['acl_new']               = 'Aggiungi nuovo valore';
$lang['acl_mod']               = 'Modifica valore';

==> dokuwiki-2016.06.26a.tgz: dokuwiki/lib/plugins/acl/lang/it/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Giorgio Vecchiocattivi <giorgio@vecchio.it>
 * @author Roberto Bolli <http://www.rbnet.it/>
 * @author Pietro Battiston toobaz@email.it
 * @author Diego Pierotto ita.translations@tiscali.it
 * @author ita.translations@tiscali.it
 * @author Lorenzo Breda <lbreda@gmail.com>
 * @author snarchio@alice.it
 * @author robocap <robocap1@gmail.com>
 * @author Osman Tekin osman.tekin93@hotmail.it
 * @author Jacopo Corbetta <jacopo.corbetta@gmail.com>
 * @author Matteo Pasotti <matteo@xquiet.eu>
 * @author snarchio@gmail.com
 */
$lang['admin_acl']             = 'Gestione Lista Controllo Accessi (ACL)';
$lang['acl_group']             = 'Gruppo:';
$lang['acl_user']              = 'Utente:';
$lang['acl_perms']             = 'Permessi per';
$lang['page']                  = 'Pagina';
$lang['namespace']             = 'Categoria';
$lang['btn_select']            = 'Seleziona';
$lang['p_user_id']             = 'L\'utente <b class="acluser">%s</b> attualmente ha i seguenti permessi sulla pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'L\'utente <b class="acluser">%s</b> attualmente ha i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi sulla pagina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'I membri del gruppo<b class="aclgroup">%s</b> attualmente hanno i seguenti permessi per la categoria <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = '<b>Inserisci un utente o gruppo</b> nel campo sopra per modificare i permessi impostati per la pagina <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = '<b>Inserisci un utente o un gruppo</b> nel campo sopra per modificare i permessi impostati per la categoria <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Nota: questi permessi non sono stati esplicitamente impostati, ma sono stati ereditati da altri gruppi o da categorie superiori.';
$lang['p_isadmin']             = 'Nota: il gruppo o utente selezionato ha sempre tutti i permessi perché è configurato come amministratore.';
$lang['p_include']             = 'I permessi più elevati includono i permessi inferiori. I permessi Crea, Carica ed Elimina si applicano soltanto alle categorie e non alle pagine.';
$lang['current']               = 'Regole ACL attuali';
$lang['where']                 = 'Pagina/Categoria';
$lang['who']                   = 'Utente/Gruppo';
$lang['perm']                  = 'Permessi';
$lang['acl_perm0']             = 'Nessuno';
$lang['acl_perm1']             = 'Lettura';
$lang['acl_perm2']             = 'Modifica';
$lang['acl_perm4']             = 'Crea';
$lang['acl_perm8']             = 'Carica';
$lang['acl_perm16']            = 'Elimina';
$lang['acl_new']               = 'Aggiungi nuovo valore';
$lang['acl_mod']               = 'Modifica valore';
